commit f40d323537daca811237aec3cd818857d8f80f62
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Jul 18 05:23:10 2025 +0700

    fix structure

commit c5a2489608d823aac330a0c488455ab3bc24caf4
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Jul 18 04:23:54 2025 +0700

    fix tests

commit 660bc6d7fa9f2a8e7548157c208f2308b99be207
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Jul 18 04:21:43 2025 +0700

    create structure

commit 60f3a795bba8111d243b6f847f3181087705f877
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Jul 18 04:01:33 2025 +0700

    Initial commit
